@@ -10,23 +10,30 @@ This needs to be run on BOTH provider and subscriber.
 DECLARE
     v_rec RECORD;
     v_sql TEXT;
+    v_rsat_args TEXT;
 BEGIN
 
     FOR v_rec IN
         SELECT quote_ident(rolname) AS rolname FROM pg_roles WHERE oid = p_roleoid
     LOOP
 
+    v_rsat_args:=pg_get_function_identity_arguments('pglogical.replication_set_add_table'::REGPROC);
+
+
     v_sql:='
     GRANT USAGE ON SCHEMA pglogical TO '||v_rec.rolname||';
     GRANT USAGE ON SCHEMA pgl_ddl_deploy TO '||v_rec.rolname||';
     GRANT EXECUTE ON FUNCTION pglogical.replicate_ddl_command(text, text[]) TO '||v_rec.rolname||';
-    GRANT EXECUTE ON FUNCTION pglogical.replication_set_add_table(name, regclass, boolean, text[], text) TO '||v_rec.rolname||';
+    GRANT EXECUTE ON FUNCTION pglogical.replication_set_add_table(' || v_rsat_args || ') TO '||v_rec.rolname||';
     GRANT EXECUTE ON FUNCTION pgl_ddl_deploy.sql_command_tags(text) TO '||v_rec.rolname||';
     GRANT EXECUTE ON FUNCTION pgl_ddl_deploy.kill_blockers(pgl_ddl_deploy.signals, name, name) TO '||v_rec.rolname||';
     GRANT INSERT, UPDATE, SELECT ON ALL TABLES IN SCHEMA pgl_ddl_deploy TO '||v_rec.rolname||';
     GRANT USAGE ON ALL SEQUENCES IN SCHEMA pgl_ddl_deploy TO '||v_rec.rolname||';
     GRANT SELECT ON ALL TABLES IN SCHEMA pglogical TO '||v_rec.rolname||';';
 
+
+
+
     EXECUTE v_sql;
     RETURN true;
     END LOOP;
