@@ -6,26 +6,25 @@ No deploy allowed if table would be added to replication
 ***/
 SET ROLE test_pgl_ddl_deploy;
 CREATE TABLE foo(id serial primary key);
-RESET ROLE;
+SET ROLE postgres;
 SELECT pgl_ddl_deploy.deploy('test1');
 SET ROLE test_pgl_ddl_deploy;
 DROP TABLE foo;
-RESET ROLE;
+SET ROLE postgres;
 
 --This should work now
 SELECT pgl_ddl_deploy.deploy('test1');
-
 --This should work
 SELECT pgl_ddl_deploy.disable('test1');
 
 --This should not work
 SET ROLE test_pgl_ddl_deploy;
 CREATE TABLE foo(id serial primary key);
-RESET ROLE;
+SET ROLE postgres;
 SELECT pgl_ddl_deploy.enable('test1');
 SET ROLE test_pgl_ddl_deploy;
 DROP TABLE foo;
-RESET ROLE;
+SET ROLE postgres;
 
 --This should work now
 SELECT pgl_ddl_deploy.enable('test1');
